<?php
// admin/index.php
session_start();
if (!isset($_SESSION['admin'])) {
    header("Location: login.php");
    exit;
}

$lang = $_SESSION['lang'] ?? 'en';
$messages = include __DIR__ . "/../lang/$lang/messages.php";
$view = $_GET['view'] ?? 'dashboard';
// Allowed views include individual report pages
$allowed = [
    'dashboard', 'payments', 'vouchers', 'sms', 'settings', 'router','users','add_user',
    'reports/sales', 'reports/payment', 'reports/success', 'reports/failed',
    'reports/vouchers', 'reports/expenses', 'reports/active_hotspot','reports/profit_loss' 
];
if (!in_array($view, $allowed)) {
    $view = 'dashboard';
}
?>
<!DOCTYPE html>
<html lang="<?= htmlspecialchars($lang) ?>">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title><?= htmlspecialchars($messages['title'] ?? 'Admin Panel') ?> | BLUE BANDO WiFi</title>
  <!-- Font Awesome -->
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css" crossorigin="anonymous" />
  <!-- AdminLTE CSS -->
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
  <!-- Google Font: Source Sans Pro -->
  <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700">
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">
  <!-- Navbar -->
  <nav class="main-header navbar navbar-expand navbar-white navbar-light">
    <!-- Left navbar links -->
    <ul class="navbar-nav">
      <!-- Sidebar toggle button-->
      <li class="nav-item">
        <a class="nav-link" data-widget="pushmenu" href="#" role="button">
          <i class="fas fa-bars"></i>
        </a>
      </li>
    </ul>
    <!-- Right navbar links -->
    <ul class="navbar-nav ml-auto">
      <li class="nav-item">
        <a href="../lang/switch.php?lang=en" class="nav-link">EN</a>
      </li>
      <li class="nav-item">
        <a href="../lang/switch.php?lang=sw" class="nav-link">SW</a>
      </li>
      <li class="nav-item">
        <a href="logout.php" class="nav-link btn btn-danger btn-sm">Logout</a>
      </li>
    </ul>
  </nav>
  <!-- /.navbar -->

  <!-- Main Sidebar Container -->
  <aside class="main-sidebar sidebar-dark-primary elevation-4">
    <!-- Brand Logo -->
    <a href="index.php" class="brand-link">
      <span class="brand-text font-weight-light">BLUE BANDO WiFi</span>
    </a>
    <!-- Sidebar -->
    <div class="sidebar">
      <!-- Sidebar Menu -->
      <nav class="mt-2">
        <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu">
          <li class="nav-item">
            <a href="?view=dashboard" class="nav-link">
              <i class="nav-icon fas fa-tachometer-alt"></i>
              <p><?= htmlspecialchars($messages['dashboard'] ?? 'Dashboard') ?></p>
            </a>
          </li>
          <li class="nav-item">
            <a href="?view=payments" class="nav-link">
              <i class="nav-icon fas fa-credit-card"></i>
              <p><?= htmlspecialchars($messages['payments'] ?? 'Payments') ?></p>
            </a>
          </li>
          <li class="nav-item">
            <a href="?view=vouchers" class="nav-link">
              <i class="nav-icon fas fa-ticket-alt"></i>
              <p><?= htmlspecialchars($messages['vouchers'] ?? 'Vouchers') ?></p>
            </a>
          </li>
          <li class="nav-item">
            <a href="?view=sms" class="nav-link">
              <i class="nav-icon fas fa-sms"></i>
              <p><?= htmlspecialchars($messages['sms_logs'] ?? 'SMS Logs') ?></p>
            </a>
          </li>
          <li class="nav-item">
            <a href="?view=settings" class="nav-link">
              <i class="nav-icon fas fa-cogs"></i>
              <p><?= htmlspecialchars($messages['settings'] ?? 'Settings') ?></p>
            </a>
          </li>
          <li class="nav-item">
            <a href="?view=router" class="nav-link">
              <i class="nav-icon fas fa-network-wired"></i>
              <p><?= htmlspecialchars($messages['router'] ?? 'Router Info') ?></p>
            </a>
          </li>


          <li class="nav-item">
          <a href="?view=users" class="nav-link">
          <i class="nav-icon fas fa-user-cog"></i>
          <p>Admin Users</p>
          </a>
         </li>
          <!-- Reports Dropdown -->
          <li class="nav-item has-treeview">
            <a href="#" class="nav-link">
              <i class="nav-icon fas fa-chart-bar"></i>
              <p>
                <?= htmlspecialchars($messages['reports'] ?? 'Reports') ?>
                <i class="right fas fa-angle-left"></i>
              </p>
            </a>
            <ul class="nav nav-treeview">

              <li class="nav-item">
                <a href="?view=reports/active_hotspot" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Active Hotspot</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/sales" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Sales Report</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/payment" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Payment Report</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/success" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Success Payment</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/failed" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Failed Payment</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/vouchers" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Created Vouchers</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/expenses" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Expenses Report</p>
                </a>
              </li>
              <li class="nav-item">
                <a href="?view=reports/profit_loss" class="nav-link">
                  <i class="far fa-circle nav-icon"></i>
                  <p>Profit/Loss</p>
                </a>
              </li>
            </ul>
          </li>
        </ul>
      </nav>
      <!-- /.sidebar-menu -->
    </div>
    <!-- /.sidebar -->
  </aside>

  <!-- Content Wrapper -->
  <div class="content-wrapper">
    <!-- Main content -->
    <section class="content pt-3">
      <div class="container-fluid">
        <?php include __DIR__ . "/views/{$view}.php"; ?>
      </div>
    </section>
    <!-- /.content -->
  </div>
  <!-- /.content-wrapper -->

  <!-- Footer -->
  <footer class="main-footer">
    <strong>&copy; <?= date("Y"); ?> BLUE BANDO WiFi.</strong> All rights reserved.
  </footer>
</div>
<!-- ./wrapper -->

<!-- jQuery -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.6.0/jquery.min.js" crossorigin="anonymous"></script>
<!-- Bootstrap 4 -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
<!-- AdminLTE App -->
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<script>
  // The AdminLTE pushmenu widget enables sidebar toggle automatically.
  // The treeview functionality (for dropdowns) is handled by AdminLTE.
  // If needed, you can add custom JS here.
</script>
</body>
</html>
