<?php
// admin/views/dashboard.php

// Load database configuration and create a connection using an absolute path
$db = include __DIR__ . '/../../config/database.php';
$conn = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($conn->connect_error) {
    die("Database connection failed: " . $conn->connect_error);
}

// Existing dashboard queries
$activeUsersResult = $conn->query("SELECT COUNT(*) as active_users FROM customers WHERE last_seen >= (NOW() - INTERVAL 15 MINUTE)");
$activeUsersData = $activeUsersResult ? $activeUsersResult->fetch_assoc() : ['active_users' => 0];
$activeUsers = $activeUsersData['active_users'];

$todaySalesResult = $conn->query("SELECT SUM(amount) as today_sales FROM payments WHERE status = 'success' AND DATE(created_at) = CURDATE()");
$todaySalesData = $todaySalesResult ? $todaySalesResult->fetch_assoc() : ['today_sales' => 0];
$todaySales = $todaySalesData['today_sales'];

$todayExpensesResult = $conn->query("SELECT SUM(amount) as today_expenses FROM expenses WHERE DATE(created_at) = CURDATE()");
$todayExpensesData = $todayExpensesResult ? $todayExpensesResult->fetch_assoc() : ['today_expenses' => 0];
$todayExpenses = $todayExpensesData['today_expenses'];

$successPaymentsResult = $conn->query("SELECT COUNT(*) as success_count FROM payments WHERE status='success' AND DATE(created_at) = CURDATE()");
$successPaymentsData = $successPaymentsResult ? $successPaymentsResult->fetch_assoc() : ['success_count' => 0];
$successPayments = $successPaymentsData['success_count'];

$failedPaymentsResult = $conn->query("SELECT COUNT(*) as failed_count FROM payments WHERE status='failed' AND DATE(created_at) = CURDATE()");
$failedPaymentsData = $failedPaymentsResult ? $failedPaymentsResult->fetch_assoc() : ['failed_count' => 0];
$failedPayments = $failedPaymentsData['failed_count'];

$recentActivityResult = $conn->query("SELECT * FROM mikrotik_logins ORDER BY login_time DESC LIMIT 10");
$recentActivity = [];
if ($recentActivityResult) {
    while ($row = $recentActivityResult->fetch_assoc()) {
        $recentActivity[] = $row;
    }
}

// --- Fetch MikroTik credentials from the settings table ---
$query = "SELECT `key`, `value` FROM settings WHERE `key` IN ('mikrotik_host', 'mikrotik_user', 'mikrotik_pass')";
$result = $conn->query($query);
$mikrotikSettings = [];
while ($row = $result->fetch_assoc()) {
    $mikrotikSettings[$row['key']] = $row['value'];
}
$routerHost = $mikrotikSettings['mikrotik_host'] ?? '10.5.50.1';
$routerUser = $mikrotikSettings['mikrotik_user'] ?? 'admin';
$routerPass = $mikrotikSettings['mikrotik_pass'] ?? 'TekiPOS92';

// --- Fetch Active Hotspot Users from MikroTik ---
require_once __DIR__ . '/../../core/MikroTikAPI.php';
$router = new MikroTikAPI($routerHost, $routerUser, $routerPass);
if ($router->connect()) {
    $activeHotspotUsers = $router->getActiveHotspotUsers();
    $router->disconnect();
} else {
    $activeHotspotUsers = [];
}
$activeHotspotUserCount = count($activeHotspotUsers);

$router = new MikroTikAPI($routerHost, $routerUser, $routerPass);
if ($router->connect()) {
    $recentRouterActivity = $router->getRecentRouterActivity(10);
    $router->disconnect();
} else {
    $recentRouterActivity = [];
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Dashboard - BLUE BANDO WiFi</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- AdminLTE CSS and Font Awesome -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
</head>
<body>
<div class="container-fluid my-4">
    <h2>Dashboard</h2>
    <div class="row">
        <!-- Active Users (Database) -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-info">
                <div class="inner">
                    <h3><?= number_format($activeUsers) ?></h3>
                    <p>Active Users (DB)</p>
                </div>
                <div class="icon">
                    <i class="fas fa-users"></i>
                </div>
            </div>
        </div>
        <!-- Active Hotspot Users (Router) -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-purple">
                <div class="inner">
                    <h3><?= number_format($activeHotspotUserCount) ?></h3>
                    <p>Active Hotspot Users</p>
                </div>
                <div class="icon">
                    <i class="fas fa-signal"></i>
                </div>
            </div>
        </div>
        <!-- Today's Sales -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-success">
                <div class="inner">
                    <h3>TZS <?= number_format($todaySales) ?></h3>
                    <p>Today's Sales</p>
                </div>
                <div class="icon">
                    <i class="fas fa-shopping-cart"></i>
                </div>
            </div>
        </div>
        <!-- Today's Expenses -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-danger">
                <div class="inner">
                    <h3>TZS <?= number_format($todayExpenses) ?></h3>
                    <p>Today's Expenses</p>
                </div>
                <div class="icon">
                    <i class="fas fa-money-bill-wave"></i>
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <!-- Success Payments -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-primary">
                <div class="inner">
                    <h3><?= number_format($successPayments) ?></h3>
                    <p>Success Payments (Today)</p>
                </div>
                <div class="icon">
                    <i class="fas fa-check-circle"></i>
                </div>
            </div>
        </div>
        <!-- Failed Payments -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-warning">
                <div class="inner">
                    <h3><?= number_format($failedPayments) ?></h3>
                    <p>Failed Payments (Today)</p>
                </div>
                <div class="icon">
                    <i class="fas fa-times-circle"></i>
                </div>
            </div>
        </div>
        <!-- Live Router Traffic -->
        <div class="col-lg-3 col-6">
            <div class="small-box bg-secondary">
                <div class="inner">
                    <h4 id="router-rx">RX: N/A</h4>
                    <h4 id="router-tx">TX: N/A</h4>
                    <p>Live Router Traffic</p>
                </div>
                <div class="icon">
                    <i class="fas fa-network-wired"></i>
                </div>
            </div>
        </div>
        <!-- Router Information -->
        <div class="col-lg-6 col-12">
            <div class="card bg-dark text-white">
                <div class="card-header">
                    <h3 class="card-title">Router Information</h3>
                </div>
                <div class="card-body" id="router-info">
                    <ul class="list-group list-group-unbordered">
                        <li class="list-group-item">
                            <b>Uptime:</b>
                            <span class="float-right" id="router-uptime">N/A</span>
                        </li>
                        <li class="list-group-item">
                            <b>RAM:</b>
                            <span class="float-right" id="router-ram">N/A</span>
                        </li>
                        <li class="list-group-item">
                            <b>Storage:</b>
                            <span class="float-right" id="router-storage">N/A</span>
                        </li>
                        <li class="list-group-item">
                            <b>CPU Load:</b>
                            <span class="float-right" id="router-cpu">N/A</span>
                        </li>
                        <li class="list-group-item">
                            <b>Temperature:</b>
                            <span class="float-right" id="router-temp">N/A</span>
                        </li>
                        <li class="list-group-item">
                            <b>Board Name:</b>
                            <span class="float-right" id="router-board">N/A</span>
                        </li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
    <!-- Recent User Activity -->
    <!-- Recent Router Activity Section -->
<div class="row mt-4">
    <div class="col-12">
        <div class="card card-primary">
            <div class="card-header">
                <h3 class="card-title">Recent Router Activity</h3>
            </div>
            <div class="card-body table-responsive p-0">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>Time</th>
                            <th>Topics</th>
                            <th>Message</th>
                        </tr>
                    </thead>
                    <tbody id="router-activity-body">
                        <tr><td colspan="3" class="text-center">Loading...</td></tr>
                    </tbody>
                </table>
            </div>
            <div class="card-footer">
                <small>Report generated on <?= date('Y-m-d H:i:s') ?></small>
            </div>
        </div>
    </div>
</div>
</div>

<!-- JavaScript to auto-refresh router info every second -->
<script>
function updateRouterStatus() {
    fetch('../api/router_status.php')
        .then(response => response.json())
        .then(data => {
            if (data.status) {
                document.getElementById('router-uptime').innerText = data.status.uptime || 'N/A';
                document.getElementById('router-ram').innerText = data.status.ram || 'N/A';
                document.getElementById('router-storage').innerText = data.status.storage || 'N/A';
                document.getElementById('router-cpu').innerText = data.status.cpu_load || 'N/A';
                document.getElementById('router-temp').innerText = data.status.temperature || 'N/A';
                document.getElementById('router-board').innerText = data.status.board_name || 'N/A';
            }
            if (data.liveTraffic) {
                document.getElementById('router-rx').innerText = 'RX: ' + (data.liveTraffic.rx || 'N/A');
                document.getElementById('router-tx').innerText = 'TX: ' + (data.liveTraffic.tx || 'N/A');
            }
        })
        .catch(error => {
            console.error('Error fetching router status:', error);
        });
}

// Refresh router status every second (1000ms)
setInterval(updateRouterStatus, 1000);
// Initial call
updateRouterStatus();



function updateRouterActivity() {
    fetch('../api/router_activity.php')
        .then(response => response.json())
        .then(data => {
            var tbody = document.getElementById('router-activity-body');
            tbody.innerHTML = ''; // Clear previous rows
            if (data.length > 0) {
                data.forEach(function(log) {
                    var row = document.createElement('tr');
                    // Adjust the keys based on your MikroTik response.
                    var timeCell = document.createElement('td');
                    timeCell.innerText = log['time'] || 'N/A';
                    var topicsCell = document.createElement('td');
                    topicsCell.innerText = log['topics'] || 'N/A';
                    var messageCell = document.createElement('td');
                    messageCell.innerText = log['message'] || 'N/A';
                    row.appendChild(timeCell);
                    row.appendChild(topicsCell);
                    row.appendChild(messageCell);
                    tbody.appendChild(row);
                });
            } else {
                tbody.innerHTML = '<tr><td colspan="3" class="text-center">No recent router activity found.</td></tr>';
            }
        })
        .catch(error => {
            console.error('Error fetching router activity:', error);
        });
}

// Call the function every 5 seconds (5000ms)
setInterval(updateRouterActivity, 5000);
updateRouterActivity(); // Initial call
</script>

<!-- Bootstrap 5 JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
