<?php
// admin/views/reports/active_hotspot.php

// Load database configuration and create a connection
$db = include __DIR__ . '/../../../config/database.php';
$conn = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($conn->connect_error) {
    die("Database connection failed: " . $conn->connect_error);
}

// Fetch MikroTik credentials from the settings table
$query = "SELECT `key`, `value` FROM settings WHERE `key` IN ('mikrotik_host', 'mikrotik_user', 'mikrotik_pass')";
$result = $conn->query($query);
$mikrotikSettings = [];
while ($row = $result->fetch_assoc()) {
    $mikrotikSettings[$row['key']] = $row['value'];
}
$conn->close();

// Assign credentials with defaults if not set
$routerHost = $mikrotikSettings['mikrotik_host'] ?? '10.5.50.1';
$routerUser = $mikrotikSettings['mikrotik_user'] ?? 'admin';
$routerPass = $mikrotikSettings['mikrotik_pass'] ?? 'TekiPOS92';

// Load the MikroTikAPI class
require_once __DIR__ . '/../../../core/MikroTikAPI.php';

$router = new MikroTikAPI($routerHost, $routerUser, $routerPass);
if ($router->connect()) {
    // Fetch active hotspot sessions (ensure your MikroTikAPI implements getActiveHotspotUsers())
    $activeUsers = $router->getActiveHotspotUsers();
    $router->disconnect();
} else {
    $activeUsers = [];
}
$totalActive = count($activeUsers);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Active Hotspot Users Report - BLUE BANDO WiFi</title>
    <!-- AdminLTE CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- Bootstrap 5 CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
</head>
<body>
<div class="container mt-4">
    <div class="card card-primary">
        <div class="card-header">
            <h3 class="card-title">Active Hotspot Users Report</h3>
            <p class="mb-0">Total Active: <?= number_format($totalActive) ?></p>
        </div>
        <div class="card-body table-responsive p-0">
            <table class="table table-bordered table-striped">
                <thead>
                    <tr>
                        <th>Server</th>
                        <th>User</th>
                        <th>Address</th>
                        <th>Mac Address</th>
                        <th>Uptime</th>
                        <th>Bytes In</th>
                        <th>Bytes Out</th>
                        <th>Time Left</th>
                        <th>Login By</th>
                        <th>Comment</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (!empty($activeUsers)): ?>
                        <?php foreach ($activeUsers as $session): ?>
                            <tr>
                                <td><?= htmlspecialchars($session['server'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['user'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['address'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['mac-address'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['uptime'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['bytes-in'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['bytes-out'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['time-left'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['login-by'] ?? 'N/A') ?></td>
                                <td><?= htmlspecialchars($session['comment'] ?? 'N/A') ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr><td colspan="10" class="text-center">No active hotspot sessions found.</td></tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
        <div class="card-footer">
            <small>Report generated on <?= date('Y-m-d H:i:s') ?></small>
        </div>
    </div>
</div>
</body>
</html>
