<?php
// admin/views/router.php

// Load the database configuration and create a connection
$db = include __DIR__ . '/../../config/database.php';
$conn = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($conn->connect_error) {
    die("Database connection failed: " . $conn->connect_error);
}

// Query the settings table for MikroTik credentials
$query = "SELECT `key`, `value` FROM settings WHERE `key` IN ('mikrotik_host', 'mikrotik_user', 'mikrotik_pass')";
$result = $conn->query($query);

$mikrotikSettings = [];
while ($row = $result->fetch_assoc()) {
    $mikrotikSettings[$row['key']] = $row['value'];
}

// Use default values if any setting is missing
$mikrotik_host = $mikrotikSettings['mikrotik_host'] ?? 'default_host';
$mikrotik_user = $mikrotikSettings['mikrotik_user'] ?? 'default_user';
$mikrotik_pass = $mikrotikSettings['mikrotik_pass'] ?? 'default_pass';

echo "<h2>Router Info</h2>";
echo "<p><strong>IP:</strong> " . htmlspecialchars($mikrotik_host) . "</p>";
echo "<p><strong>Username:</strong> " . htmlspecialchars($mikrotik_user) . "</p>";

// Load the MikroTik API class using an absolute path
require_once __DIR__ . '/../../core/MikroTikAPI.php';

// Create an instance of the MikroTikAPI class using the credentials from the database
$router = new MikroTikAPI($mikrotik_host, $mikrotik_user, $mikrotik_pass);

// Check the connection to the router
if ($router->connect()) {
    echo "<p><strong>Status:</strong> ✅ Connected</p>";
    $router->disconnect();
} else {
    echo "<p><strong>Status:</strong> ❌ Not reachable</p>";
}
?>
