<?php
// admin/views/settings.php

// Load database configuration and create a new connection
$db = include __DIR__ . '/../../config/database.php';
$conn = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($conn->connect_error) {
    die("Database connection failed: " . $conn->connect_error);
}

// Process form submission to update settings
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    foreach ($_POST as $key => $value) {
        // Use a prepared statement to update each setting
        $stmt = $conn->prepare("UPDATE settings SET value = ? WHERE `key` = ?");
        $stmt->bind_param("ss", $value, $key);
        $stmt->execute();
    }
    echo "<p class='alert alert-success'>Settings updated successfully!</p>";
}

// Retrieve current settings
$result = $conn->query("SELECT `key`, value FROM settings");
$settings = [];
while ($row = $result->fetch_assoc()) {
    $settings[$row['key']] = $row['value'];
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Settings</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="container mt-4">
    <h2>Settings</h2>
    <form method="POST">
        <div class="mb-3">
            <label>App Name</label>
            <input type="text" name="app_name" class="form-control" value="<?= htmlspecialchars($settings['app_name'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>MikroTik Host</label>
            <input type="text" name="mikrotik_host" class="form-control" value="<?= htmlspecialchars($settings['mikrotik_host'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>MikroTik Username</label>
            <input type="text" name="mikrotik_user" class="form-control" value="<?= htmlspecialchars($settings['mikrotik_user'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>MikroTik Password</label>
            <input type="password" name="mikrotik_pass" class="form-control" value="<?= htmlspecialchars($settings['mikrotik_pass'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>Selcom Merchant ID</label>
            <input type="text" name="selcom_merchant_id" class="form-control" value="<?= htmlspecialchars($settings['selcom_merchant_id'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>Selcom API Key</label>
            <input type="text" name="selcom_api_key" class="form-control" value="<?= htmlspecialchars($settings['selcom_api_key'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>Selcom API Secret</label>
            <input type="text" name="selcom_api_secret" class="form-control" value="<?= htmlspecialchars($settings['selcom_api_secret'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>Beem API Key</label>
            <input type="text" name="beem_api_key" class="form-control" value="<?= htmlspecialchars($settings['beem_api_key'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>Beem Secret Key</label>
            <input type="text" name="beem_secret_key" class="form-control" value="<?= htmlspecialchars($settings['beem_secret_key'] ?? '') ?>">
        </div>
        <div class="mb-3">
            <label>Beem Sender Name</label>
            <input type="text" name="beem_sender_name" class="form-control" value="<?= htmlspecialchars($settings['beem_sender_name'] ?? '') ?>">
        </div>
        <button type="submit" class="btn btn-primary">Save Settings</button>
    </form>
</body>
</html>
