<?php
// admin/views/vouchers.php

// Load database configuration and create a connection using an absolute path
$db = include __DIR__ . '/../../config/database.php';
$conn = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($conn->connect_error) {
    die("Database connection failed: " . $conn->connect_error);
}

// Handle voucher creation form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Generate a random voucher code (8-character uppercase)
    $code = strtoupper(substr(md5(uniqid()), 0, 8));
    // Get the time limit in minutes; default to 60 minutes if not provided
    $time_limit = $_POST['time_limit'] ?? 60;
    // Get the profile; default to 'default' if not provided
    $profile = $_POST['profile'] ?? 'default';
    
    // Calculate expiry time: current time plus the time limit (in minutes)
    $expires_at = date('Y-m-d H:i:s', strtotime("+{$time_limit} minutes"));
    
    // Prepare and execute the insert statement with the expires_at field
    $stmt = $conn->prepare("INSERT INTO vouchers (code, time_limit, profile, expires_at) VALUES (?, ?, ?, ?)");
    $stmt->bind_param("siss", $code, $time_limit, $profile, $expires_at);
    $stmt->execute();
    
    echo "<p class='text-success'>Voucher Created: <strong>$code</strong> (Expires at: $expires_at)</p>";
}

// Retrieve the latest 50 vouchers
$vouchers = $conn->query("SELECT * FROM vouchers ORDER BY id DESC LIMIT 50");
?>

<h2>Vouchers</h2>

<form method="POST" class="mb-4">
    <label>Time Limit (minutes): <input type="number" name="time_limit" value="60"></label>
    <label>Profile: <input type="text" name="profile" value="default"></label>
    <button type="submit">Generate Voucher</button>
</form>

<table border="1" cellpadding="6">
    <thead>
        <tr>
            <th>Code</th>
            <th>Status</th>
            <th>Time Limit (minutes)</th>
            <th>Profile</th>
            <th>Used At</th>
            <th>Expires At</th>
        </tr>
    </thead>
    <tbody>
        <?php while($v = $vouchers->fetch_assoc()): ?>
        <tr>
            <td><?= $v['code'] ?></td>
            <td><?= $v['status'] ?></td>
            <td><?= $v['time_limit'] ?></td>
            <td><?= $v['profile'] ?></td>
            <td><?= $v['used_at'] ?></td>
            <td><?= $v['expires_at'] ?></td>
        </tr>
        <?php endwhile; ?>
    </tbody>
</table>
