<?php
// api/pay.php

// Load database configuration and create a connection
$db = include __DIR__ . '/../config/database.php';
$conn = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($conn->connect_error) {
    http_response_code(500);
    echo json_encode(['success' => false, 'error' => 'Database connection error: ' . $conn->connect_error]);
    exit;
}

header('Content-Type: application/json');

// Read POST parameters
$phone = trim($_POST['phone'] ?? '');
$amount = trim($_POST['amount'] ?? '');

if (!$phone || !$amount) {
    echo json_encode(['success' => false, 'error' => 'Missing phone number or amount']);
    exit;
}

// Simulate payment success:
// Generate a unique voucher code
$voucherCode = strtoupper(substr(md5(uniqid()), 0, 8));

// For simulation, we use a default time limit and profile; you can extend this with package mapping logic
$time_limit = 60; // in minutes (example)
$profile = 'default';

// Insert the voucher into the vouchers table (ensure your table has the required columns)
$stmt = $conn->prepare("INSERT INTO vouchers (code, time_limit, profile, status, created_at) VALUES (?, ?, ?, 'available', NOW())");
$stmt->bind_param("sis", $voucherCode, $time_limit, $profile);
$stmt->execute();
$stmt->close();

// Insert a payment record marking it as successful (simulate)
$transaction_id = uniqid('txn_');
$stmt = $conn->prepare("INSERT INTO payments (phone_number, amount, status, transaction_id, created_at) VALUES (?, ?, 'success', ?, NOW())");
$stmt->bind_param("sds", $phone, $amount, $transaction_id);
$stmt->execute();
$stmt->close();

$conn->close();


// Send SMS using Beem Africa integration
require_once __DIR__ . '/../core/BeemSMS.php';
$creds = include __DIR__ . '/../config/credentials.php';
$sms = new BeemSMS($creds['beem']);
$message = "Your payment was successful. Your voucher code is: " . $voucherCode;
$result = $sms->sendSMS($phone, $message);
error_log(print_r($result, true));  // Log the API response for debugging

// Return JSON response indicating success and include the voucher code
echo json_encode(['success' => true, 'code' => $voucherCode]);


?>
