<?php
// api/voucher.php

require_once '../config/database.php';
require_once '../config/credentials.php';

$db = require '../config/database.php';

$mysqli = new mysqli($db['host'], $db['user'], $db['pass'], $db['dbname']);
if ($mysqli->connect_error) {
    http_response_code(500);
    echo json_encode(['error' => 'Database connection failed']);
    exit;
}

header('Content-Type: application/json');

// Generate voucher code
function generateVoucherCode($length = 8) {
    return strtoupper(substr(md5(uniqid(rand(), true)), 0, $length));
}

// Package profile mapping
$packageProfiles = [
    '500' => ['profile' => 'profile_6h', 'duration' => 6],
    '1000' => ['profile' => 'profile_24h', 'duration' => 24],
    '2000' => ['profile' => 'profile_3d', 'duration' => 72],
    '5000' => ['profile' => 'profile_7d', 'duration' => 168],
    '15000' => ['profile' => 'profile_30d', 'duration' => 720],
];

$action = $_GET['action'] ?? '';

if ($action === 'generate') {
    $code = generateVoucherCode();
    $amount = $_POST['amount'] ?? 500;
    $package = $packageProfiles[$amount] ?? $packageProfiles['500'];

    $profile = $package['profile'];
    $time_limit = $package['duration'] * 60; // in minutes
    $expires_at = date('Y-m-d H:i:s', strtotime("+{$package['duration']} hours"));

    $stmt = $mysqli->prepare("INSERT INTO vouchers (code, time_limit, profile, status, used_at, created_at, expires_at) VALUES (?, ?, ?, 'available', NULL, NOW(), ?)");
    $stmt->bind_param("siss", $code, $time_limit, $profile, $expires_at);

    if ($stmt->execute()) {
        echo json_encode(['success' => true, 'code' => $code, 'profile' => $profile, 'expires_at' => $expires_at]);
    } else {
        echo json_encode(['success' => false, 'error' => 'Failed to create voucher']);
    }
} elseif ($action === 'list') {
    $result = $mysqli->query("SELECT * FROM vouchers ORDER BY id DESC LIMIT 100");
    $vouchers = [];
    while ($row = $result->fetch_assoc()) {
        $vouchers[] = $row;
    }
    echo json_encode($vouchers);
} elseif ($action === 'use') {
    $code = $_POST['code'] ?? '';
    $stmt = $mysqli->prepare("UPDATE vouchers SET status = 'used', used_at = NOW() WHERE code = ? AND status = 'available'");
    $stmt->bind_param("s", $code);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['success' => false, 'error' => 'Invalid or already used code']);
    }
} else {
    echo json_encode(['error' => 'Invalid action']);
}
?>
